from setuptools import setup, find_packages

setup(
    name='mada_holidays',
    version='1.0',
    packages=find_packages(),
    description='Un package qui montre tous les jours fériés à Madagascar',
    author='TOTOZAFY Johnathon Wesley',
    author_email='hei.johnathon.2@gmail.com',
    url='https://github.com/Johnathon47/mada_holidays',
    python_requires='>=3.6',
    install_requires=[],
)